@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/shell-maker
-;; Package-Version: 0.84.4
-;; Package-Revision: 63f178f925b5
+;; Package-Version: 0.84.8
+;; Package-Revision: 6eafe72de916
 ;; Package-Requires: ((emacs "27.1"))
 
 ;; This package is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 
 ;;; Code:
 
-(defconst shell-maker-version "0.84.4")
+(defconst shell-maker-version "0.84.8")
 
 (require 'comint)
 (require 'goto-addr)
@@ -102,6 +102,13 @@ For example:
   :type 'directory
   :group 'shell-maker)
 
+(defcustom shell-maker-curl-executable "curl"
+  "Path to the curl executable.
+Can be a simple command name like \"curl\" if it's in PATH,
+or an absolute path like \"/usr/local/bin/curl\"."
+  :type 'string
+  :group 'shell-maker)
+
 (defcustom shell-maker-forget-file-after-clear nil
   "If non-nil, reset file path after clear command."
   :type 'boolean
@@ -154,6 +161,7 @@ For example:
   :parent comint-mode-map
   :doc "Base keymap for `shell-maker' based modes."
   "S-<return>" #'newline
+  "<remap> <rename-buffer>" #'shell-maker-rename-buffer
   "<remap> <save-buffer>" #'shell-maker-save-session-transcript
   "C-M-h" #'shell-maker-mark-output)
 
@@ -201,6 +209,7 @@ Set MODE-LINE-NAME to override the mode line name."
         `(define-derived-mode ,(shell-maker-major-mode config) comint-mode
            ,(or mode-line-name (shell-maker-config-name config))
            ,(format "Major mode for %s shell." (shell-maker-config-name config))
+           (keymap-set shell-maker-mode-map "<remap> <comint-delchar-or-maybe-eof>" #'delete-char)
            (keymap-set shell-maker-mode-map "<remap> <comint-send-input>" #'shell-maker-submit)
            (keymap-set shell-maker-mode-map "<remap> <comint-interrupt-subjob>" #'shell-maker-interrupt)
            (keymap-set shell-maker-mode-map "<remap> <comint-history-isearch-backward-regexp>" #'shell-maker-search-history))))
@@ -1016,7 +1025,7 @@ and TIMEOUT: defaults to 600ms."
       (with-temp-file data-file
         (setq-local coding-system-for-write encoding)
         (insert (shell-maker--json-encode data))))
-    (append (list "curl" url
+    (append (list shell-maker-curl-executable url
                   "--fail-with-body"
                   "--no-progress-meter"
                   "-m" (number-to-string timeout))
@@ -1273,7 +1282,7 @@ returned list is of the form:
 
 (defun shell-maker--curl-version-supported ()
   "Return t if curl version is 7.76 or newer, nil otherwise."
-  (let ((curl-version-string (shell-command-to-string (concat "curl --version "))))
+  (let ((curl-version-string (shell-command-to-string (concat shell-maker-curl-executable " --version "))))
     (when (string-match "\\([0-9]+\\.[0-9]+\\.[0-9]+\\)" curl-version-string)
       (let ((version (match-string 1 curl-version-string)))
         (version<= "7.76" version)))))
